      subroutine boundary_zuvm
c
c=======================================================================
c                                                                    ===
c  This subroutine extends values of uvel,vvel at v-points to the    ===
c  grid boundary i=1|imtm1 ; j=1:jmtm1                               ===
#if defined coast
c  Coastal boundaries are not updated. (Not true, but it should be)  ===
#endif
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <scalar.h>
#include <fields.h>
#include <fieldsbar.h>
#include <fullwd.h>
#include <onedim.h>
#include <workspa.h>
#include <bndata.h>
#include <options.h>
#include <iounits.h>
#include <sinfo.h>
#if defined freesurf & defined ext_tide & !defined mixtideonly 
# include <tidesp.h>
#endif
#if defined freesurf & defined transbc
# include <vertslabs.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i
#ifndef cyclic
     &        ,j
#endif
      FLOAT
     &     delu,delv,fac,fx,psne,psnw,psse,pssw
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Orlanski radiation (implicit).
c-----------------------------------------------------------------------
c
      if(iopt(4).eq.3) then
c
#ifndef cyclic
        do 10 j = 2, jmtm2
          call zrobc_ori (j,west)
          call zrobc_ori (j,east)
  10    continue
c
#endif
        call zrobc_ori (1,south)
        call zrobc_ori (jmtm1,north)
c
c-----------------------------------------------------------------------
c  Modified Orlanski radiation (implicit).
c-----------------------------------------------------------------------
c
      elseif(iopt(4).eq.4) then
c
#ifndef cyclic
        do 20 j = 2, jmtm2
          call zrobc_moi (j,west)
          call zrobc_moi (j,east)
  20    continue
c
#endif
        call zrobc_moi (1,south)
        call zrobc_moi (jmtm1,north)
c
c-----------------------------------------------------------------------
c  Linear extrapolation
c-----------------------------------------------------------------------
c
      elseif(iopt(4).eq.5) then
c
        do 30 i = 2, imum1
          zum(i,1)=c2*zum(i,2)-zum(i,3)
          zvm(i,1)=c2*zvm(i,2)-zvm(i,3)
          zum(i,jmtm1)=c2*zum(i,jmtm2)-zum(i,jmtm2-1)
          zvm(i,jmtm1)=c2*zvm(i,jmtm2)-zvm(i,jmtm2-1)
  30    continue
c
#ifndef cyclic
        do 40 j=2,jmtm2
          zum(1,j)=c2*zum(2,j)-zum(3,j)
          zvm(1,j)=c2*zvm(2,j)-zvm(3,j)
          zum(imtm1,j)=c2*zum(imtm2,j)-zum(imtm2-1,j)
          zvm(imtm1,j)=c2*zvm(imtm2,j)-zvm(imtm2-1,j)
  40    continue
c
        zum(1,1)         = p5*(zum(2,1)+zum(1,2))
        zum(imtm1,1)     = p5*(zum(imtm2,1)+zum(imtm1,2))
        zum(imtm1,jmtm1) = p5*(zum(imtm1,jmtm2)+zum(imtm2,jmtm1))
        zum(1,jmtm1)     = p5*(zum(1,jmtm2)+zum(2,jmtm1))
c
        zvm(1,1)         = p5*(zvm(2,1)+zvm(1,2))
        zvm(imtm1,1)     = p5*(zvm(imtm2,1)+zvm(imtm1,2))
        zvm(imtm1,jmtm1) = p5*(zvm(imtm1,jmtm2)+zvm(imtm2,jmtm1))
        zvm(1,jmtm1)     = p5*(zvm(1,jmtm2)+zvm(2,jmtm1))
c
#else
        zum(1,1)=zum(imtm1,1)
        zvm(1,1)=zvm(imtm1,1)
        zum(imt,1)=zum(2,1)
        zvm(imt,1)=zvm(2,1)
c
        zum(1,jmtm1)=zum(imtm1,jmtm1)
        zvm(1,jmtm1)=zvm(imtm1,jmtm1)
        zum(imt,jmtm1)=zum(2,jmtm1)
        zvm(imt,jmtm1)=zvm(2,jmtm1)
c
#endif
c-----------------------------------------------------------------------
c  Constant (zeroth order) extrapolation
c-----------------------------------------------------------------------
c
      elseif(iopt(4).eq.6) then
c
        do 50 i = 2, imum1
          zum(i,1)=zum(i,2)
          zvm(i,1)=zvm(i,2)
          zum(i,jmtm1)=zum(i,jmtm2)
          zvm(i,jmtm1)=zvm(i,jmtm2)
  50    continue
c
#ifndef cyclic
        do 60 j = 2, jmtm2
          zum(1,j)=zum(2,j)
          zvm(1,j)=zvm(2,j)
          zum(imtm1,j)=zum(imtm2,j)
          zvm(imtm1,j)=zvm(imtm2,j)
  60    continue
c
        zum(1,1)         = zum(2,2)
        zum(imtm1,1)     = zum(imtm2,2)
        zum(imtm1,jmtm1) = zum(imtm2,jmtm2)
        zum(1,jmtm1)     = zum(2,jmtm2)
c
        zvm(1,1)         = zvm(2,2)
        zvm(imtm1,1)     = zvm(imtm2,2)
        zvm(imtm1,jmtm1) = zvm(imtm2,jmtm2)
        zvm(1,jmtm1)     = zvm(2,jmtm2)
c
#else
        zum(1,1)=zum(imtm1,1)
        zvm(1,1)=zvm(imtm1,1)
        zum(imt,1)=zum(2,1)
        zvm(imt,1)=zvm(2,1)
c
        zum(1,jmtm1)=zum(imtm1,jmtm1)
        zvm(1,jmtm1)=zvm(imtm1,jmtm1)
        zum(imt,jmtm1)=zum(2,jmtm1)
        zvm(imt,jmtm1)=zvm(2,jmtm1)
c
#endif
c-----------------------------------------------------------------------
c  Provided or Provided-Orlanski (implicit).(Technically on ubaro,vbaro).
c-----------------------------------------------------------------------
c
      elseif ((iopt(4).eq.1) .or. (iopt(4).eq.7)) then
c
c  Set time scaling.
c
        fx=alphap*c2*omega*c2dtsf
c
        if((mix.eq.1).and.eb) then
           fac=c1
        else
           if((mxp.ne.0).or.(mix.ne.0)) then
              fac=p5
           else
              fac=c1
           endif
        endif
        fx=fac*fx
c
c  Make a guess for surface pressure/elevation at advanced time, one
c  point inside boundary.
c
        call psbym1
c
c  Construct PO corrections.
c
        if (iopt(4).eq.7) then
c
c     Calculate PO corrections.
c
#ifndef cyclic
           do 90 j = 2, jmtm2
             call zrobc_por (j,west)
             call zrobc_por (j,east)
  90       continue
c
#endif
           call zrobc_por (1,south)
           call zrobc_por (jmtm1,north)
c
c     Ensure PO corrections are consistent with imposed surface elevation.
c
#ifdef freesurf
           if (iopt(3).ne.7) then
#endif
              call rsettrans
#ifdef freesurf
            else
              call bndytrans
           endif
#endif
c
        endif
c
c  Set boundary values.
#if defined freesurf & defined ext_tide & !defined mixtideonly & defined transbc
c  Assume tides satisfy linear transport divergence.
#endif
c
#ifndef cyclic
        do 70 j = 2, jmtm2
           if (fkmq(1,j).gt.c0) then
# if !defined freesurf | (!defined transbc & !defined nest2larger)
              delu = ubaroo(j,1,itbp,west) - ubarob(1,j)
              delv = vbaroo(j,1,itbp,west) - vbarob(1,j)
# else
              delu = utrano(j,1,itbp,west) - ubarob(1,j)*hdvbf(1,j)
              delv = vtrano(j,1,itbp,west) - vbarob(1,j)*hdvbf(1,j)
# endif
# if defined freesurf & defined ext_tide & !defined mixtideonly
#  ifndef transbc
              delu = delu + ubartd(1,j,itda)
              delv = delv + vbartd(1,j,itda)
#  else
              delu = delu + ubartd(1,j,itda)*hdv(1,j)
              delv = delv + vbartd(1,j,itda)*hdv(1,j)
#  endif
# endif
              if (iopt(4).eq.7) then
                 delu = delu + dubaro(j,itbp,west)
                 delv = delv + dvbaro(j,itbp,west)
              end if
# if !defined freesurf | (!defined transbc & !defined nest2larger)
              zum(1,j) = delu - fx*sine(1,j)*delv
              zvm(1,j) = delv + fx*sine(1,j)*delu
# else
              zum(1,j) = (delu - fx*sine(1,j)*delv)/hdvcf(1,j)
              zvm(1,j) = (delv + fx*sine(1,j)*delu)/hdvcf(1,j)
# endif
              psnw = alphap*(po(j+1,1,west)+pb(1,j+1))+gammabar*p(1,j+1)
              psne = alphap*(pbc0(j+1,2,itbp,west)
#if defined freesurf & defined ext_tide & !defined mixtideonly 
     &                       + grav*srftd(2,j+1,itda)
#endif
     &                       + detatby(j+1,2,itbp,west)*grav
     &                       + pb(2,j+1)) + gammabar*p(2,j+1)
              pssw = alphap*(po(j,1,west)+pb(1,j))+gammabar*p(1,j)
              psse = alphap*(pbc0(j,2,itbp,west)
#if defined freesurf & defined ext_tide & !defined mixtideonly 
     &                       + grav*srftd(2,j,itda)
#endif
     &                       + detatby(j,2,itbp,west)*grav
     &                       + pb(2,j)) + gammabar*p(2,j)
              zum(1,j) = zum(1,j) + c2dtsf*
     &                   ((psne-psnw)+(psse-pssw))*csr(j)*dxu2r(1)
              zvm(1,j) = zvm(1,j) + c2dtsf*
     &                   ((psne-psse)+(psnw-pssw))*dyu2r(j)
           end if
c
           if (fkmq(imu,j).gt.c0) then
# if !defined freesurf | (!defined transbc & !defined nest2larger)
              delu = ubaroo(j,1,itbp,east) - ubarob(imu,j)
              delv = vbaroo(j,1,itbp,east) - vbarob(imu,j)
# else
              delu = utrano(j,1,itbp,east) - ubarob(imu,j)*hdvbf(imu,j)
              delv = vtrano(j,1,itbp,east) - vbarob(imu,j)*hdvbf(imu,j)
# endif
# if defined freesurf & defined ext_tide & !defined mixtideonly
#  ifndef transbc
              delu = delu + ubartd(imu,j,itda)
              delv = delv + vbartd(imu,j,itda)
#  else
              delu = delu + ubartd(imu,j,itda)*hdv(imu,j)
              delv = delv + vbartd(imu,j,itda)*hdv(imu,j)
#  endif
# endif
              if (iopt(4).eq.7) then
                 delu = delu + dubaro(j,itbp,east)
                 delv = delv + dvbaro(j,itbp,east)
              end if
# if !defined freesurf | (!defined transbc & !defined nest2larger)
              zum(imu,j) = delu - fx*sine(imu,j)*delv
              zvm(imu,j) = delv + fx*sine(imu,j)*delu
# else
              zum(imu,j) = (delu - fx*sine(imu,j)*delv)/hdvcf(imu,j)
              zvm(imu,j) = (delv + fx*sine(imu,j)*delu)/hdvcf(imu,j)
# endif
              psne = alphap*(po(j+1,1,east)+pb(imt,j+1)) +
     &               gammabar*p(imt,j+1)
              psnw = alphap*(pbc0(j+1,2,itbp,east)
#if defined freesurf & defined ext_tide & !defined mixtideonly 
     &                       + grav*srftd(imtm1,j+1,itda)
#endif
     &                       + detatby(j+1,2,itbp,east)*grav
     &                       + pb(imtm1,j+1)) + gammabar*p(imtm1,j+1)
              psse = alphap*(po(j,1,east)+pb(imt,j))+gammabar*p(imt,j)
              pssw = alphap*(pbc0(j,2,itbp,east)
#if defined freesurf & defined ext_tide & !defined mixtideonly 
     &                       + grav*srftd(imtm1,j,itda)
#endif
     &                       + detatby(j,2,itbp,east)*grav
     &                       + pb(imtm1,j)) + gammabar*p(imtm1,j)
              zum(imu,j) = zum(imu,j) + c2dtsf*
     &                     ((psne-psnw)+(psse-pssw))*csr(j)*dxu2r(imu)
              zvm(imu,j) =zvm(imu,j) + c2dtsf*
     &                     ((psne-psse)+(psnw-pssw))*dyu2r(j)
           end if
  70    continue
c
#endif
c
        do 80 i = 1, imu
           if (fkmq(i,1).gt.c0) then
#if !defined freesurf | (!defined transbc & !defined nest2larger)
              delu = ubaroo(i,1,itbp,south) - ubarob(i,1)
              delv = vbaroo(i,1,itbp,south) - vbarob(i,1)
#else
              delu = utrano(i,1,itbp,south) - ubarob(i,1)*hdvbf(i,1)
              delv = vtrano(i,1,itbp,south) - vbarob(i,1)*hdvbf(i,1)
#endif
#if defined freesurf & defined ext_tide & !defined mixtideonly 
# ifndef transbc
              delu = delu + ubartd(i,1,itda)
              delv = delv + vbartd(i,1,itda)
# else
              delu = delu + ubartd(i,1,itda)*hdv(i,1)
              delv = delv + vbartd(i,1,itda)*hdv(i,1)
# endif
#endif
              if (iopt(4).eq.7) then
                 delu = delu + dubaro(i,itbp,south)
                 delv = delv + dvbaro(i,itbp,south)
              end if
#if !defined freesurf | (!defined transbc & !defined nest2larger)
              zum(i,1) = delu - fx*sine(i,1)*delv
              zvm(i,1) = delv + fx*sine(i,1)*delu
#else
              zum(i,1) = (delu - fx*sine(i,1)*delv) / hdvcf(i,1)
              zvm(i,1) = (delv + fx*sine(i,1)*delu) / hdvcf(i,1)
#endif
              psnw = alphap*(pbc0(i,2,itbp,south)
#if defined freesurf & defined ext_tide & !defined mixtideonly 
     &                       + grav*srftd(i,2,itda)
#endif
     &                       + detatby(i,2,itbp,south)*grav
     &                       + pb(i,2)) + gammabar*p(i,2)
              psne = alphap*(pbc0(i+1,2,itbp,south)
#if defined freesurf & defined ext_tide & !defined mixtideonly 
     &                       + grav*srftd(i+1,2,itda)
#endif
     &                       + detatby(i+1,2,itbp,south)*grav
     &                       + pb(i+1,2)) + gammabar*p(i+1,2)
              pssw = alphap*(po(i,1,south) + pb(i,1)) + gammabar*p(i,1)
              psse = alphap*(po(i+1,1,south) + pb(i+1,1))
     &               + gammabar*p(i+1,1)
              zum(i,1) = zum(i,1) + c2dtsf*
     &                   ((psne-psnw)+(psse-pssw))*csr(1)*dxu2r(i)
              zvm(i,1) = zvm(i,1) + c2dtsf*
     &                   ((psne-psse)+(psnw-pssw))*dyu2r(1)
           end if
c
           if (fkmq(i,jmtm1).gt.c0) then
#if !defined freesurf | (!defined transbc & !defined nest2larger)
              delu = ubaroo(i,1,itbp,north) - ubarob(i,jmtm1)
              delv = vbaroo(i,1,itbp,north) - vbarob(i,jmtm1)
#else
              delu=utrano(i,1,itbp,north)-ubarob(i,jmtm1)*hdvbf(i,jmtm1)
              delv=vtrano(i,1,itbp,north)-vbarob(i,jmtm1)*hdvbf(i,jmtm1)
#endif
#if defined freesurf & defined ext_tide & !defined mixtideonly 
# ifndef transbc
              delu = delu + ubartd(i,jmtm1,itda)
              delv = delv + vbartd(i,jmtm1,itda)
# else
              delu = delu + ubartd(i,jmtm1,itda)*hdv(i,jmtm1)
              delv = delv + vbartd(i,jmtm1,itda)*hdv(i,jmtm1)
# endif
#endif
              if (iopt(4).eq.7) then
                 delu = delu + dubaro(i,itbp,north)
                 delv = delv + dvbaro(i,itbp,north)
              end if
#if !defined freesurf | (!defined transbc & !defined nest2larger)
              zum(i,jmtm1) = delu - fx*sine(i,jmtm1)*delv
              zvm(i,jmtm1) = delv + fx*sine(i,jmtm1)*delu
#else
              zum(i,jmtm1) = (delu-fx*sine(i,jmtm1)*delv)/hdvcf(i,jmtm1)
              zvm(i,jmtm1) = (delv+fx*sine(i,jmtm1)*delu)/hdvcf(i,jmtm1)
#endif
              pssw = alphap*(pbc0(i,2,itbp,north)
#if defined freesurf & defined ext_tide & !defined mixtideonly 
     &                       + grav*srftd(i,jmtm1,itda)
#endif
     &                       + detatby(i,2,itbp,north)*grav
     &                       + pb(i,jmtm1)) + gammabar*p(i,jmtm1)
              psse = alphap*(pbc0(i+1,2,itbp,north)
#if defined freesurf & defined ext_tide & !defined mixtideonly 
     &                       + grav*srftd(i+1,jmtm1,itda)
#endif
     &                       + detatby(i+1,2,itbp,north)*grav
     &                       + pb(i+1,jmtm1)) + gammabar*p(i+1,jmtm1)
              psnw = alphap*(po(i,1,north)+pb(i,jmt)) +gammabar*p(i,jmt)
              psne = alphap*(po(i+1,1,north) + pb(i+1,jmt))
     &               + gammabar*p(i+1,jmt)
              zum(i,jmtm1) = zum(i,jmtm1) + c2dtsf*
     &                     ((psne-psnw)+(psse-pssw))*csr(jmtm1)*dxu2r(i)
              zvm(i,jmtm1) = zvm(i,jmtm1) + c2dtsf*
     &                            ((psne-psse)+(psnw-pssw))*dyu2r(jmtm1)
           end if
  80    continue
c
c-----------------------------------------------------------------------
c  Illegal option.
c-----------------------------------------------------------------------
c
      elseif (iopt(4).ne.2) then
        write(stdout,901) iopt(4)
        call exitus('BOUNDARY_ZUVM')
      endif
c
      return
c
901   format(/'Error:  BOUNDARY_ZUVM: ',
     * 'invalid boundary condition on zum, zvm, IOPT(4) =',i4)
c
      end
