      subroutine fltpbn (pwk2)
c
c=======================================================================
c                                                                    ===
c  This routine filters the radiation-type estimate for the transport===
c  streamfunction along the outer boundary.                          ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     PWK2   Time change guess for transport.           (real array) ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /FILTDAT/                                                         ===
c                                                                    ===
c     NORDP    transport: order of the Shapiro filter.      (integer)===
c     NORDV    velocity: order of the Shapiro filter.       (integer)===
c     NTIMP    transport: number of times to apply filter.  (integer)===
c     NTIMV    velocity: number of times to apply filter.   (integer)===
c                                                                    ===
c  /FULLWD/                                                          ===
c                                                                    ===
c     IEXT    Extraction I-coords, external bndy.   (integer vector) ===
c     JEXT    Extraction J-coords, external bndy.   (integer vector) ===
c     NOEXT   Length of external boundary.          (integer)        ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     PWK2   Filtered time change guess for transport.  (real array) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
#if defined coast & !defined surfpress
c     CNSTPBY,  SHAP1DC                                              ===
#elif defined surfpress
c     SHAP1DC,  SHAP1DO                                              ===
#else
c     SHAP1DC                                                        ===
#endif
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <filtdat.h>
#include <fullwd.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer n,pbord,pbtim
#ifdef surfpress
     &        ,m
#endif
      logical first
      real    pwk1(maxext),pwk2(imt,jmt)
c
      save first,pbord,pbtim
c
      data first/.true./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Initialize filter parameters on first call.
c-----------------------------------------------------------------------
c
      if (first) then
         if (nordpb.ne.0) then
            pbord = nordpb
          elseif (nordp.ne.0) then
            pbord = nordp
          else
            pbord = nordv
         endif
         if (ntimpb.ne.0) then
            pbtim = ntimpb
          elseif (ntimp.ne.0) then
            pbtim = ntimp
          else
            pbtim = ntimv
         endif
         first = .false.
      endif
c
#if defined coast & !defined surfpress
c-----------------------------------------------------------------------
c  Ensure constant streamfunction along the coasts.
c-----------------------------------------------------------------------
c
      call cnstpby (pwk2)
c
#endif
#ifndef surfpress
c-----------------------------------------------------------------------
c  Extract external boundary data into vector.
c-----------------------------------------------------------------------
c
      do 10 n = 1, noext
         pwk1(n) = pwk2(iext(n),jext(n))
  10  continue
c
c-----------------------------------------------------------------------
c  Filter boundary data.
c-----------------------------------------------------------------------
c
      do 20 n = 1, pbtim
         call shap1dc (pwk1,noext,pbord)
  20  continue
c
c-----------------------------------------------------------------------
c  Place filtered external boundary data into array.
c-----------------------------------------------------------------------
c
      do 30 n = 1, noext
         pwk2(iext(n),jext(n)) = pwk1(n)
  30  continue
c
#else
c-----------------------------------------------------------------------
c  Loop over all separate external segments.
c-----------------------------------------------------------------------
c
      if (noext.gt.0) then
c
         do 40 n = 1, noext
c
c  Extract external boundary data into vector.
c
            do 10 m = 1, lenext(n)
               pwk1(m) = pwk2(iext(m,n),jext(m,n))
  10        continue
c
c  Filter boundary data.
c
            do 20 m = 1, pbtim
               call shap1do (pwk1,lenext(n),pbord)
  20        continue
c
c  Place filtered external boundary data into array.
c
            do 30 m = 1, lenext(n)
               pwk2(iext(m,n),jext(m,n)) = pwk1(m)
  30        continue
  40     continue
c
c-----------------------------------------------------------------------
c  Filter single, continuous external segment.
c-----------------------------------------------------------------------
c
      else
c
c  Extract external boundary data into vector.
c
         do 50 m = 1, lenext(1)
            pwk1(m) = pwk2(iext(m,1),jext(m,1))
  50     continue
c
c  Filter boundary data.
c
         do 60 m = 1, pbtim
            call shap1dc (pwk1,lenext(1),pbord)
  60     continue
c
c  Place filtered external boundary data into array.
c
         do 70 m = 1, lenext(1)
            pwk2(iext(m,1),jext(m,1)) = pwk1(m)
  70     continue
c
      end if
#endif
#if defined coast & !defined surfpress
c-----------------------------------------------------------------------
c  Ensure constant streamfunction along the coasts.
c-----------------------------------------------------------------------
c
      call cnstpby (pwk2)
c
#endif
      return
      end
