      subroutine reset_advect (iunit)
C
C=======================================================================
C                                                                    ===
C  This routine updates barotropic advection accounting for volume   ===
c  box changes from time TAU to time TAU+1. The internal velocities  ===
c  is  reset to vertically averaged zero mean for time TAU+1.        ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <vertslabs.h>
#include <onedim.h>
#include <voldat.h>
#include <workspa.h>
#include <bndata.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer nstr,nend
      parameter (nstr=nt*imtkm, nend=nstr+2*imtkm-1)
c
      integer i,ip,iunit,j,k,nrmb
      FLOAT
     &        umz,vmz,fx
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Roll over all slabs
c-----------------------------------------------------------------------
c
      do 150 j = 1, jmtm1
c
c    Extract velocity data.  Reset thicknesses.
c
        call oget(iunit,nslab,(j-1)*nslab+1,ta)
        call get_thick (j,vgrid,dzvqz(1,1,0),dzzvqz(1,1,0),kmp1)
c
c    Reset baroclinicity to internal velocity.
c
        do 30 i = 1, imt
           ip=(j-1)*imt+i
           umz=c0
           vmz=c0        
           fx=c0
           do 10 k = 1, km
              umz=umz+dzvqz(i,k,0)*xu(ip,k)
              vmz=vmz+dzvqz(i,k,0)*xv(ip,k)
              fx=fx+dzvqz(i,k,0)
  10       continue
           umz=umz/fx
           vmz=vmz/fx
           do 20 k=1,km
              xu(ip,k)=xu(ip,k)-umz
              xv(ip,k)=xv(ip,k)-vmz
              ua(i,k)=xu(ip,k)
              va(i,k)=xv(ip,k)
  20       continue
  30    continue
c
c    Put revised velocity data back to disk.
c
        call oput(iunit,nslab,(j-1)*nslab+1,ta)
c
c ---------------------------------------------------------------
c --- Reset baroclinicity to internal velocity boundary data. ---
c ---------------------------------------------------------------
c
        do 80 nrmb = 1, 3
c
c    Western boundary.
c
           ip=nrmb
           umz=c0
           vmz=c0        
           fx=c0
           do 40 k = 1, km
              umz=umz+dzvqz(ip,k,0)*ubc0(ip,k,nrmb,itbp,west)
              vmz=vmz+dzvqz(ip,k,0)*vbc0(ip,k,nrmb,itbp,west)
              fx=fx+dzvqz(ip,k,0)
  40       continue
           umz=umz/fx
           vmz=vmz/fx
           do 50 k=1,km
              ubc0(ip,k,nrmb,itbp,west)=ubc0(ip,k,nrmb,itbp,west)-umz
              vbc0(ip,k,nrmb,itbp,west)=vbc0(ip,k,nrmb,itbp,west)-vmz
  50       continue
c
c    Eastern boundary.
c
           ip=imu+1-nrmb
           umz=c0
           vmz=c0        
           fx=c0
           do 60 k = 1, km
              umz=umz+dzvqz(ip,k,0)*ubc0(ip,k,nrmb,itbp,east)
              vmz=vmz+dzvqz(ip,k,0)*vbc0(ip,k,nrmb,itbp,east)
              fx=fx+dzvqz(ip,k,0)
  60       continue
           umz=umz/fx
           vmz=vmz/fx
           do 70 k=1,km
              ubc0(ip,k,nrmb,itbp,east)=ubc0(ip,k,nrmb,itbp,east)-umz
              vbc0(ip,k,nrmb,itbp,east)=vbc0(ip,k,nrmb,itbp,east)-vmz
  70       continue
  80    continue
c
c    Southern boundary.
c
        nrmb = j
        if (nrmb.lt.4) then
           do 110 i = 1, imt
              umz=c0
              vmz=c0        
              fx=c0
              do 90 k = 1, km
                 umz=umz+dzvqz(i,k,0)*ubc0(i,k,nrmb,itbp,south)
                 vmz=vmz+dzvqz(i,k,0)*vbc0(i,k,nrmb,itbp,south)
                 fx=fx+dzvqz(i,k,0)
  90          continue
              umz=umz/fx
              vmz=vmz/fx
              do 100 k=1,km
                 ubc0(i,k,nrmb,itbp,south)=ubc0(i,k,nrmb,itbp,south)-umz
                 vbc0(i,k,nrmb,itbp,south)=vbc0(i,k,nrmb,itbp,south)-vmz
 100          continue
 110       continue
        endif
c
c    Northern boundary.
c
        nrmb = jmt - j
        if (nrmb.lt.4) then
           do 140 i = 1, imt
              umz=c0
              vmz=c0        
              fx=c0
              do 120 k = 1, km
                 umz=umz+dzvqz(i,k,0)*ubc0(i,k,nrmb,itbp,north)
                 vmz=vmz+dzvqz(i,k,0)*vbc0(i,k,nrmb,itbp,north)
                 fx=fx+dzvqz(i,k,0)
 120          continue
              umz=umz/fx
              vmz=vmz/fx
              do 130 k=1,km
                 ubc0(i,k,nrmb,itbp,north)=ubc0(i,k,nrmb,itbp,north)-umz
                 vbc0(i,k,nrmb,itbp,north)=vbc0(i,k,nrmb,itbp,north)-vmz
 130          continue
 140       continue
        endif
c
 150  continue
c
      return
      end


