      subroutine rmmn_fs (fld,j)
c
c=======================================================================
c                                                                    ===
c  This routine removes the vertical mean from the given baroclinic  ===
c  velocity component.  The computation is simplified by the fact    ===
c  that the vertical grid perturbations are a simple rescaling that  ===
c  cancels out in this computation.                                  ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     FLD    Original velocity component.     (real array)           ===
c     J      Current slab index.              (integer)              ===
c     Z0     Unperturbed depths.              (real array)           ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /VERTICAL/                                                        ===
c                                                                    ===
c     DZV   Thicknesses of the velocity vertical boxes.   (real; cm) ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     FLD    Baroclinic velocity component.           (real array)   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <vertical.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j,k
      FLOAT
     &      sumdz,vmean
      FLOAT
     &      fld(imt,km)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Loop over entire slab, reinterpolating the field.
c-----------------------------------------------------------------------
c
      do 30 i = 1, imt
c
c    Compute spurious vertical mean.
c
         sumdz = dzv(i,j,1)
         vmean = fld(i,1)*dzv(i,j,1)
c
         do 10 k = 2, km
            sumdz = sumdz + dzv(i,j,k)
            vmean = vmean + fld(i,k)*dzv(i,j,k)
  10     continue
c
c    Remove spurious vertical mean.
c
         vmean = vmean/sumdz
c
         do 20 k = 1, km
            fld(i,k) = fld(i,k) - vmean
  20     continue
  30  continue
c
      return
      end
