      subroutine rsettrans
c
c=======================================================================
c                                                                    ===
c  Reset the Provided Orlanski (PO) corrections to barotropic        ===
c  velocity to not contribute to the net transport in/out of the     ===
c  domain.                                                           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BNDATA/                                                          ===
c                                                                    ===
c     DUBARO   Zonal PO corrections.       (real)                    ===
c     DVBARO   Meridional PO corrections.  (real)                    ===
c                                                                    ===
c  /ONEDIM/                                                          ===
c                                                                    ===
c     CS    cosine metric factors at velocity points.       (real)   ===
c     DXU   zonal grid spacing across velocity boxes.       (real)   ===
c     DYU   meridional grid spacing across velocity boxes.  (real)   ===
c                                                                    ===
#ifdef coast
c  /FULLWD/                                                          ===
c                                                                    ===
c     IEQ   ending ocean x-index at velocity points.     (integer)   ===
c     ISQ   starting ocean x-index at velocity points.   (integer)   ===
c     JEQ   ending ocean y-index at velocity points.     (integer)   ===
c     JSQ   starting ocean y-index at velocity points.   (integer)   ===
c                                                                    ===
#endif
#if !defined freesurf | !defined transbc
c  /VERTSLABS/                                                       ===
c                                                                    ===
# if defined freesurf
c     HDVCF   bottom topography at the velocity points               ===
c             with respect to mean free surface.         (real)      ===
# else
c     HDV     bottom topography at the velocity points.  (real)      ===
# endif
c                                                                    ===
#endif
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BNDATA/                                                          ===
c                                                                    ===
c     DUBARO   Zonal zero-transport PO corrections.       (real)     ===
c     DVBARO   Meridional zero-transport PO corrections.  (real)     ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  none                                                              ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <bndata.h>
#include <onedim.h>
#ifdef coast
# include <fullwd.h>
#endif
#if !defined freesurf | !defined transbc
# include <vertslabs.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,iend,istr,j,jend,jstr
#ifdef coast
     &        ,l
#endif
      FLOAT
     &     netatran,nettran
      FLOAT
     &     nvel(ijmx,4)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute net transports of the corrections.
c-----------------------------------------------------------------------
c
c  South
c
      nettran  = c0
      netatran = c0
c
#ifdef coast
      do 20, l = 1, lseg
         istr = isq(2,l)
         if (istr.eq.2) istr=1
         iend = ieq(2,l)
         if (iend.eq.imum1) iend=imu
         if ((istr.gt.0) .and. (istr.le.iend)) then
#else
         istr = 1
         iend = imu
#endif
         nvel(istr,south) = - abs(dvbaro(istr,itbp,south))
         nvel(iend,south) = - abs(dvbaro(iend,itbp,south))
#if defined freesurf & defined transbc
         nettran = nettran - p5*cs(1)*(dvbaro(istr,itbp,south)*dxu(istr)
     &                             + dvbaro(iend,itbp,south)*dxu(iend) )
         netatran = netatran - p5*cs(1)*(nvel(istr,south)*dxu(istr) +
     &                                      nvel(iend,south)*dxu(iend) )
#elif defined freesurf
         nettran = nettran - p5*cs(1)*(
     &                 dvbaro(istr,itbp,south)*dxu(istr)*hdvcf(istr,1)
     &               + dvbaro(iend,itbp,south)*dxu(iend)*hdvcf(iend,1) )
         netatran = netatran - p5*cs(1)*(
     &                        nvel(istr,south)*hdvcf(istr,1)*dxu(istr) +
     &                        nvel(iend,south)*hdvcf(iend,1)*dxu(iend) )
#else
         nettran = nettran - p5*cs(1)*(
     &                   dvbaro(istr,itbp,south)*dxu(istr)*hdv(istr,1)
     &                 + dvbaro(iend,itbp,south)*dxu(iend)*hdv(iend,1) )
         netatran = netatran - p5*cs(1)*(
     &                          nvel(istr,south)*hdv(istr,1)*dxu(istr) +
     &                          nvel(iend,south)*hdv(iend,1)*dxu(iend) )
#endif
         do 10 i = (istr+1), (iend-1)
            nvel(i,south) = - abs(dvbaro(i,itbp,south))
#if defined freesurf & defined transbc
            nettran = nettran - dvbaro(i,itbp,south)*cs(1)*dxu(i)
            netatran = netatran - cs(1)*nvel(i,south)*dxu(i)
#elif defined freesurf
            nettran = nettran - cs(1)*
     &                            dvbaro(i,itbp,south)*dxu(i)*hdvcf(i,1)
            netatran = netatran - cs(1)*nvel(i,south)*hdvcf(i,1)*dxu(i)
#else
            nettran = nettran - cs(1)*
     &                              dvbaro(i,itbp,south)*dxu(i)*hdv(i,1)
            netatran = netatran - cs(1)*nvel(i,south)*hdv(i,1)*dxu(i)
#endif
  10     continue
#ifdef coast
         endif
  20  continue
#endif
c
c  North
c
#ifdef coast
      do 40, l = 1, lseg
         istr = isq(jmtm2,l)
         if (istr.eq.2) istr=1
         iend = ieq(jmtm2,l)
         if (iend.eq.imum1) iend=imu
         if ((istr.gt.0) .and. (istr.le.iend)) then
#else
         istr = 1
         iend = imu
#endif
         nvel(istr,north) = abs(dvbaro(istr,itbp,north))
         nvel(iend,north) = abs(dvbaro(iend,itbp,north))
#if defined freesurf & defined transbc
         nettran=nettran+p5*cs(jmtm1)*(dvbaro(istr,itbp,north)*dxu(istr)
     &                             + dvbaro(iend,itbp,north)*dxu(iend) )
         netatran = netatran + p5*cs(jmtm1)*(nvel(istr,north)*dxu(istr)
     &                                    + nvel(iend,north)*dxu(iend) )
#elif defined freesurf
         nettran = nettran + p5*cs(jmtm1)*(
     &             dvbaro(istr,itbp,north)*dxu(istr)*hdvcf(istr,jmtm1)
     &           + dvbaro(iend,itbp,north)*dxu(iend)*hdvcf(iend,jmtm1) )
         netatran = netatran + p5*cs(jmtm1)*(
     &                    nvel(istr,north)*hdvcf(istr,jmtm1)*dxu(istr) +
     &                    nvel(iend,north)*hdvcf(iend,jmtm1)*dxu(iend) )
#else
         nettran = nettran + p5*cs(jmtm1)*(
     &               dvbaro(istr,itbp,north)*dxu(istr)*hdv(istr,jmtm1)
     &             + dvbaro(iend,itbp,north)*dxu(iend)*hdv(iend,jmtm1) )
         netatran = netatran + p5*cs(jmtm1)*(
     &                      nvel(istr,north)*hdv(istr,jmtm1)*dxu(istr) +
     &                      nvel(iend,north)*hdv(iend,jmtm1)*dxu(iend) )
#endif
         do 30 i = (istr+1), (iend-1)
            nvel(i,north) = abs(dvbaro(i,itbp,north))
#if defined freesurf & defined transbc
            nettran = nettran + dvbaro(i,itbp,north)*cs(jmtm1)*dxu(i)
            netatran = netatran + cs(jmtm1)*nvel(i,north)*dxu(i)
#elif defined freesurf
            nettran = nettran + cs(jmtm1)*
     &                        dvbaro(i,itbp,north)*dxu(i)*hdvcf(i,jmtm1)
            netatran = netatran 
     &                   + cs(jmtm1)*nvel(i,north)*hdvcf(i,jmtm1)*dxu(i)
#else
            nettran = nettran + cs(jmtm1)*
     &                          dvbaro(i,itbp,north)*dxu(i)*hdv(i,jmtm1)
            netatran = netatran
     &                     + cs(jmtm1)*nvel(i,north)*hdv(i,jmtm1)*dxu(i)
#endif
  30     continue
#ifdef coast
         endif
  40  continue
#endif
c
c  East
c
#ifdef coast
      do 60, l = 1, lseg
         jstr = jsq(imum1,l)
         if (jstr.eq.2) jstr=1
         jend = jeq(imum1,l)
         if (jend.eq.jmtm2) jend=jmtm1
         if ((jstr.gt.0) .and. (jstr.le.jend)) then
#else
         jstr = 1
         jend = jmtm1
#endif
         nvel(jstr,east) = abs(dubaro(jstr,itbp,east))
         nvel(jend,east) = abs(dubaro(jend,itbp,east))
#if defined freesurf & defined transbc
         nettran = nettran + p5*(dubaro(jstr,itbp,east)*dyu(jstr)
     &                             + dubaro(jend,itbp,east)*dyu(jend) )
         netatran = netatran + p5*(nvel(jstr,east)*dyu(jstr)
     &                                    + nvel(jend,east)*dyu(jend) )
#elif defined freesurf
         nettran = nettran + p5*(
     &             dubaro(jstr,itbp,east)*dyu(jstr)*hdvcf(imu,jstr)
     &           + dubaro(jend,itbp,east)*dyu(jend)*hdvcf(imu,jend) )
         netatran = netatran + p5*(
     &                    nvel(jstr,east)*hdvcf(imu,jstr)*dyu(jstr) +
     &                    nvel(jend,east)*hdvcf(imu,jend)*dyu(jend) )
#else
         nettran = nettran + p5*(
     &               dubaro(jstr,itbp,east)*dyu(jstr)*hdv(imu,jstr)
     &             + dubaro(jend,itbp,east)*dyu(jend)*hdv(imu,jend) )
         netatran = netatran + p5*(
     &                      nvel(jstr,east)*hdv(imu,jstr)*dyu(jstr) +
     &                      nvel(jend,east)*hdv(imu,jend)*dyu(jend) )
#endif
         do 50 j = (jstr+1), (jend-1)
            nvel(j,east) = abs(dubaro(j,itbp,east))
#if defined freesurf & defined transbc
            nettran = nettran + dubaro(j,itbp,east)*dyu(j)
            netatran = netatran + nvel(j,east)*dyu(j)
#elif defined freesurf
            nettran = nettran + dubaro(j,itbp,east)*dyu(j)*hdvcf(imu,j)
            netatran = netatran + nvel(j,east)*hdvcf(imu,j)*dyu(j)
#else
            nettran = nettran + dubaro(j,itbp,east)*dyu(j)*hdv(imu,j)
            netatran = netatran + nvel(j,east)*hdv(imu,j)*dyu(j)
#endif
  50     continue
#ifdef coast
         endif
  60  continue
#endif
c
c  West
c
#ifdef coast
      do 80, l = 1, lseg
         jstr = jsq(2,l)
         if (jstr.eq.2) jstr=1
         jend = jeq(2,l)
         if (jend.eq.jmtm2) jend=jmtm1
         if ((jstr.gt.0) .and. (jstr.le.jend)) then
#else
         jstr = 1
         jend = jmtm1
#endif
         nvel(jstr,west) = - abs(dubaro(jstr,itbp,west))
         nvel(jend,west) = - abs(dubaro(jend,itbp,west))
#if defined freesurf & defined transbc
         nettran = nettran - p5*(dubaro(jstr,itbp,west)*dyu(jstr)
     &                             + dubaro(jend,itbp,west)*dyu(jend) )
         netatran = netatran - p5*(nvel(jstr,west)*dyu(jstr)
     &                                    + nvel(jend,west)*dyu(jend) )
#elif defined freesurf
         nettran = nettran - p5*(
     &             dubaro(jstr,itbp,west)*dyu(jstr)*hdvcf(1,jstr)
     &           + dubaro(jend,itbp,west)*dyu(jend)*hdvcf(1,jend) )
         netatran = netatran - p5*(
     &                    nvel(jstr,west)*hdvcf(1,jstr)*dyu(jstr) +
     &                    nvel(jend,west)*hdvcf(1,jend)*dyu(jend) )
#else
         nettran = nettran - p5*(
     &               dubaro(jstr,itbp,west)*dyu(jstr)*hdv(1,jstr)
     &             + dubaro(jend,itbp,west)*dyu(jend)*hdv(1,jend) )
         netatran = netatran - p5*(
     &                      nvel(jstr,west)*hdv(1,jstr)*dyu(jstr) +
     &                      nvel(jend,west)*hdv(1,jend)*dyu(jend) )
#endif
         do 70 j = (jstr+1), (jend-1)
            nvel(j,west) = - abs(dubaro(j,itbp,west))
#if defined freesurf & defined transbc
            nettran = nettran - dubaro(j,itbp,west)*dyu(j)
            netatran = netatran - nvel(j,west)*dyu(j)
#elif defined freesurf
            nettran = nettran - dubaro(j,itbp,west)*dyu(j)*hdvcf(1,j)
            netatran = netatran - nvel(j,west)*hdvcf(1,j)*dyu(j)
#else
            nettran = nettran - dubaro(j,itbp,west)*dyu(j)*hdv(1,j)
            netatran = netatran - nvel(j,west)*hdv(1,j)*dyu(j)
#endif
  70     continue
#ifdef coast
         endif
  80  continue
#endif
c
c-----------------------------------------------------------------------
c  Compute zero-transport correction scale.
c-----------------------------------------------------------------------
c
c  No correction needed if PO changes add no net transport.
c
      if (nettran.eq.c0) return
c
c  Construct correction factor.  (Note:  NETATRAN can not be zero
C  and still get by above test.)
c
      nettran = -nettran/netatran
c
c-----------------------------------------------------------------------
c  Modify PO correction for zero net transport.
c-----------------------------------------------------------------------
c
c  South
c
#ifdef coast
      do 100, l = 1, lseg
         istr = isq(2,l)
         if (istr.eq.2) istr=1
         iend = ieq(2,l)
         if (iend.eq.imum1) iend=imu
         if ((istr.gt.0) .and. (istr.le.iend)) then
#else
         istr = 1
         iend = imu
#endif
         do 90 i = istr, iend
            dvbaro(i,itbp,south) = dvbaro(i,itbp,south)
     &                             + nettran*nvel(i,south)
  90     continue
#ifdef coast
         endif
 100  continue
#endif
c
c  North
c
#ifdef coast
      do 120, l = 1, lseg
         istr = isq(jmtm2,l)
         if (istr.eq.2) istr=1
         iend = ieq(jmtm2,l)
         if (iend.eq.imum1) iend=imu
         if ((istr.gt.0) .and. (istr.le.iend)) then
#else
         istr = 1
         iend = imu
#endif
         do 110 i = istr, iend
            dvbaro(i,itbp,north) = dvbaro(i,itbp,north)
     &                             + nettran*nvel(i,north)
 110     continue
#ifdef coast
         endif
 120  continue
#endif
c
c  East
c
#ifdef coast
      do 140, l = 1, lseg
         jstr = jsq(imum1,l)
         if (jstr.eq.2) jstr=1
         jend = jeq(imum1,l)
         if (jend.eq.jmtm2) jend=jmtm1
         if ((jstr.gt.0) .and. (jstr.le.jend)) then
#else
         jstr = 1
         jend = jmtm1
#endif
         do 130 j = jstr, jend
            dubaro(j,itbp,east) = dubaro(j,itbp,east)
     &                             + nettran*nvel(j,east)
 130     continue
#ifdef coast
         endif
 140  continue
#endif
c
c  West
c
#ifdef coast
      do 160, l = 1, lseg
         jstr = jsq(2,l)
         if (jstr.eq.2) jstr=1
         jend = jeq(2,l)
         if (jend.eq.jmtm2) jend=jmtm1
         if ((jstr.gt.0) .and. (jstr.le.jend)) then
#else
         jstr = 1
         jend = jmtm1
#endif
         do 150 j = jstr, jend
            dubaro(j,itbp,west) = dubaro(j,itbp,west)
     &                             + nettran*nvel(j,west)
 150     continue
#ifdef coast
         endif
 160  continue
#endif
c
      return
      end
