      subroutine scltrn (ubarob,etavb,npt,bry,nboff,utranb)
c
c=======================================================================
c                                                                    ===
c  This routine scales the boundary barotropic velocity component to ===
c  the boundary transport component.                                 ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     UBAROB   Boundary barotropic velocity.        (real vector)    ===
c     ETAVB    Boundary surface elevation, Vgrid.   (real vector)    ===
c     NPT      Number of points along boundary.     (integer)        ===
c     BRY      Boundary indicator.                  (integer)        ===
c     NBOFF    Normal boundary offset.              (integer)        ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /VERTSLABS/                                                       ===
c                                                                    ===
c     HDV   bottom topography at velocity points.   (real array)     ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     UTRANB   Boundary transport.                  (real vector)    ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     none                                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <vertslabs.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer boff,bry,n,nboff,npt
      integer dby(4),by(4)
      FLOAT
     &      etavb(npt),ubarob(npt),utranb(npt)
c
      save dby,by
c
      data dby /1,1,-1,-1/
      data  by /1,1,imtm1,jmtm1/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set boundary constant index.
c-----------------------------------------------------------------------
c
      boff = by(bry) + dby(bry)*nboff
c
c-----------------------------------------------------------------------
c  Construct transport component.
c-----------------------------------------------------------------------
c
      if (mod(bry,2).eq.1) then
         do 10 n = 1, npt
            utranb(n) = (hdv(boff,n)+etavb(n))*ubarob(n)
  10     continue
       else
         do 20 n = 1, npt
            utranb(n) = (hdv(n,boff)+etavb(n))*ubarob(n)
  20     continue
      end if
c
      return
      end
