c
c=======================================================================
c  Include file "tidesp.h"
c=======================================================================
#ifndef rmdocinc
c
c  FUWTD    tidal flux through western wall.
c  FVNTD    tidal flux through northern wall.
c  FVSTDU   tidal flux through southern wall of velocity boxes.
c  FVSTDT   tidal flux through southern wall of tracer boxes.
# if defined surfpress & defined freesurf
c  ITD      pointer to tidal elevation at present time step.
c  ITDA     pointer to tidal elevation at advanced time step.
c  ITDB     pointer to tidal elevation at previous time step.
# endif
c  SADV     scaling factor on tidal advection.
# if !defined surfpress | !defined freesurf
c  SRFTD    tidal elevation, present time step.
# else
c  SRFTD    tidal elevation: previous, present & advanced time steps.
c  PTDTX    d2PsTide/dtdx: prev, present & adv time steps.
c  PTDTY    d2PsTide/dtdy: prev, present & adv time steps.
c  UBARTD   zonal barotropic tidal velocity: prev, present & adv time steps.
c  VBARTD   meridional barotropic tidal vel.: prev, present & adv time steps.
# endif
c  BTIDE    square of bottom tidal velocities, row J, present time step.
c  BTIDEP   square of bottom tidal velocities, row J+1, present time step.
c  UTIDE    zonal component of tidal velocity, row J, present timestep.
c  UTIDEM   zonal component of tidal velocity, row J-1, present timestep.
c  UTIDEP   zonal component of tidal velocity, row J+1, present timestep.
c  VTIDE    meridional component of tidal velocity, row J, present timestep.
c  VTIDEM   meridional component of tidal velocity, row J-1, present timestep.
c  VTIDEP   meridional component of tidal velocity, row J+1, present timestep.
# ifdef tide_zero
c  TUUX     residual tidal stress uux
c  TVUY     residual tidal stress vuy
c  TWUZ     residual tidal stress wuz
c  TUVX     residual tidal stress uvx
c  TVVY     residual tidal stress vvy
c  TWVZ     residual tidal stress wvz
# endif
c
c=======================================================================
#endif
c
#if !defined surfpress | !defined freesurf
      FLOAT
     *      srftd (imt,jmt),
#else
      integer itdb,itd,itda
      FLOAT
     *      ptdtx(imt,jmt,0:2),ptdty(imt,jmt,0:2),srftd(imt,jmt,0:2),
     *      ubartd(imt,jmt,0:2),vbartd(imt,jmt,0:2),
#endif
     *      utide (imt,km),vtide (imt,km),
     *      utidem(imt,km),vtidem(imt,km),
     *      btide (imt),btidep(imt),
     *      utidep(imt,km),vtidep(imt,km)
     *      ,fuwtd (imt,km),fvntd(imt,km),fvstdu(imt,km),fvstdt(imt,km)
#ifdef tide_zero
     *      ,tuux(imt,km),tvuy(imt,km),twuz(imt,km)
     *      ,tuvx(imt,km),tvvy(imt,km),twvz(imt,km)
#endif
#ifdef advtide0
     *      ,sadv
#endif
c
#if !defined surfpress | !defined freesurf
      common /tidesp/ srftd,btide,btidep,
#else
      common /itidesp/ itdb,itd,itda
      common /ftidesp/ ptdtx,ptdty,srftd,btide,btidep,ubartd,vbartd,
#endif
     *                utide,vtide,utidem,vtidem,utidep,vtidep
     *                ,fuwtd,fvntd,fvstdu,fvstdt
#ifdef tide_zero
     *                ,tuux,tvuy,twuz,tuvx,tvvy,twvz
#endif
#ifdef advtide0
     *                ,sadv
#endif
